/*
 * Copyright (c) 2005-2006 Extreme! Lab, Indiana University. All rights reserved.
 *
 * This software is open source. See the bottom of this file for the license.
 *
 * $Id: XBayaToolBar.java,v 1.4 2006/11/20 18:35:07 sshirasu Exp $
 */

package edu.indiana.extreme.xbaya.gui;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.JToolBar;
import javax.swing.border.Border;

import edu.indiana.extreme.xbaya.XBayaEngine;
import edu.indiana.extreme.xbaya.graph.GraphException;

/**
 * @author Satoshi Shirasuna
 */
public class XBayaToolBar implements XBayaComponent {

    private XBayaEngine engine;

    private JToolBar toolbar;

    /**
     * Creates a toolbar.
     * 
     * @param client
     */
    public XBayaToolBar(XBayaEngine client) {
        this.engine = client;
        init();
    }

    /**
     * Returns the toolbar.
     * 
     * @return The toolbar
     */
    public JComponent getSwingComponent() {
        return this.toolbar;
    }

    private void init() {

        this.toolbar = new JToolBar();
        this.toolbar.setFloatable(false);
        Border border = BorderFactory.createEtchedBorder();
        this.toolbar.setBorder(border);

        JButton addNodeButton = new JButton("Add Node");
        addNodeButton.addActionListener(new AbstractAction() {
            private static final long serialVersionUID = 1L;

            public void actionPerformed(ActionEvent event) {
                try {
                    XBayaToolBar.this.engine.getGUI().addNode();
                } catch (RuntimeException e) {
                    XBayaToolBar.this.engine.getGUI().getErrorWindow().error(
                            ErrorMessages.UNEXPECTED_ERROR, e);
                } catch (Error e) {
                    XBayaToolBar.this.engine.getGUI().getErrorWindow().error(
                            ErrorMessages.UNEXPECTED_ERROR, e);
                }
            }
        });

        JButton removeNodeButton = new JButton("Remove Node");
        removeNodeButton.addActionListener(new AbstractAction() {
            private static final long serialVersionUID = 1L;

            public void actionPerformed(ActionEvent event) {
                try {
                    XBayaToolBar.this.engine.getGUI().getGraphCanvas()
                            .removeSelectedNode();
                } catch (GraphException e) {
                    // Should not happen
                    XBayaToolBar.this.engine.getGUI().getErrorWindow().error(
                            ErrorMessages.UNEXPECTED_ERROR, e);
                } catch (RuntimeException e) {
                    XBayaToolBar.this.engine.getGUI().getErrorWindow().error(
                            ErrorMessages.UNEXPECTED_ERROR, e);
                } catch (Error e) {
                    XBayaToolBar.this.engine.getGUI().getErrorWindow().error(
                            ErrorMessages.UNEXPECTED_ERROR, e);
                }
            }
        });

        JButton connectEdgeButton = new JButton("Connect/Disconnect");
        connectEdgeButton.addActionListener(new AbstractAction() {
            private static final long serialVersionUID = 1L;

            public void actionPerformed(ActionEvent event) {
                try {
                    XBayaToolBar.this.engine.getGUI().getGraphCanvas()
                            .addOrRemoveEdge();
                } catch (RuntimeException e) {
                    XBayaToolBar.this.engine.getGUI().getErrorWindow().error(
                            ErrorMessages.UNEXPECTED_ERROR, e);
                } catch (Error e) {
                    XBayaToolBar.this.engine.getGUI().getErrorWindow().error(
                            ErrorMessages.UNEXPECTED_ERROR, e);
                }
            }
        });

        this.toolbar.add(addNodeButton);
        this.toolbar.add(removeNodeButton);
        this.toolbar.addSeparator();
        this.toolbar.add(connectEdgeButton);
    }

}

/*
 * Indiana University Extreme! Lab Software License, Version 1.2
 * 
 * Copyright (c) 2005-2006 The Trustees of Indiana University. All rights
 * reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1) All redistributions of source code must retain the above copyright notice,
 * the list of authors in the original source code, this list of conditions and
 * the disclaimer listed in this license;
 * 
 * 2) All redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the disclaimer listed in this license in
 * the documentation and/or other materials provided with the distribution;
 * 
 * 3) Any documentation included with all redistributions must include the
 * following acknowledgement:
 * 
 * "This product includes software developed by the Indiana University Extreme!
 * Lab. For further information please visit http://www.extreme.indiana.edu/"
 * 
 * Alternatively, this acknowledgment may appear in the software itself, and
 * wherever such third-party acknowledgments normally appear.
 * 
 * 4) The name "Indiana University" or "Indiana University Extreme! Lab" shall
 * not be used to endorse or promote products derived from this software without
 * prior written permission from Indiana University. For written permission,
 * please contact http://www.extreme.indiana.edu/.
 * 
 * 5) Products derived from this software may not use "Indiana University" name
 * nor may "Indiana University" appear in their name, without prior written
 * permission of the Indiana University.
 * 
 * Indiana University provides no reassurances that the source code provided
 * does not infringe the patent or any other intellectual property rights of any
 * other entity. Indiana University disclaims any liability to any recipient for
 * claims brought by any other entity based on infringement of intellectual
 * property rights or otherwise.
 * 
 * LICENSEE UNDERSTANDS THAT SOFTWARE IS PROVIDED "AS IS" FOR WHICH NO
 * WARRANTIES AS TO CAPABILITIES OR ACCURACY ARE MADE. INDIANA UNIVERSITY GIVES
 * NO WARRANTIES AND MAKES NO REPRESENTATION THAT SOFTWARE IS FREE OF
 * INFRINGEMENT OF THIRD PARTY PATENT, COPYRIGHT, OR OTHER PROPRIETARY RIGHTS.
 * INDIANA UNIVERSITY MAKES NO WARRANTIES THAT SOFTWARE IS FREE FROM "BUGS",
 * "VIRUSES", "TROJAN HORSES", "TRAP DOORS", "WORMS", OR OTHER HARMFUL CODE.
 * LICENSEE ASSUMES THE ENTIRE RISK AS TO THE PERFORMANCE OF SOFTWARE AND/OR
 * ASSOCIATED MATERIALS, AND TO THE PERFORMANCE AND VALIDITY OF INFORMATION
 * GENERATED USING SOFTWARE.
 */
